#' The QuickJSR package.
#'
#' @description An interface to the QuickJS lightweight Javascript engine
#'
#' @name QuickJSR-package
#' @aliases QuickJSR
#' @useDynLib QuickJSR, .registration = TRUE
#'
#' @importFrom jsonlite fromJSON
#' @importFrom R6 R6Class
#' @importFrom Rcpp sourceCpp Rcpp.plugin.maker
#'
"_PACKAGE"
